==> cdk-gitlab-2.0.95.tar.gz: cdk-gitlab-2.0.95/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-gitlab",
    "version": "2.0.95",
    "description": "High level CDK construct to provision GitLab integrations with AWS",
    "license": "Apache-2.0",
    "url": "https://github.com/pahud/cdk-gitlab.git",
    "long_description_content_type": "text/markdown",
    "author": "Pahud Hsieh<pahudnet@gmail.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/pahud/cdk-gitlab.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_gitlab",
        "cdk_gitlab._jsii"
    ],
    "package_data": {
        "cdk_gitlab._jsii": [
            "cdk-gitlab@2.0.95.jsii.tgz"
        ],
        "cdk_gitlab": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.1.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.61.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> cdk-gitlab-2.0.120.tar.gz: cdk-gitlab-2.0.120/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "cdk-gitlab",
    "version": "2.0.120",
    "description": "High level CDK construct to provision GitLab integrations with AWS",
    "license": "Apache-2.0",
    "url": "https://github.com/pahud/cdk-gitlab.git",
    "long_description_content_type": "text/markdown",
    "author": "Pahud Hsieh<pahudnet@gmail.com>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/pahud/cdk-gitlab.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "cdk_gitlab",
        "cdk_gitlab._jsii"
    ],
    "package_data": {
        "cdk_gitlab._jsii": [
            "cdk-gitlab@2.0.120.jsii.tgz"
        ],
        "cdk_gitlab": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk-lib>=2.1.0, <3.0.0",
        "constructs>=10.0.5, <11.0.0",
        "jsii>=1.63.1, <2.0.0",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
